@@ -26,22 +26,28 @@
 #include <qnamespace.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qpushbutton.h>
 #include <qtextcodec.h>
 #include <qtextstream.h>
-//Added by qt3to4:
+#include <qregexp.h>
 #include <QKeyEvent>
 #include <QHBoxLayout>
-#include <QBoxLayout>
 #include <QVBoxLayout>
 #include <QSplitter>
-#include <kdebug.h>
-#include <kfiledialog.h>
-#include <klocale.h>
+#include <QDebug>
+#include <QFileDialog>
+#include <QDialogButtonBox>
+#include <QPushButton>
+
 #include <kmessagebox.h>
-#include <qregexp.h>
-#include <kconfiggroup.h>
+#include <KLocalizedString>
+#include <KConfigGroup>
+#include <KConfig>
+#include <KHelpClient>
+#include <KGuiItem>
+
 #include "misc.h"
+#include "debug.h"
+
 using Cervisia::ResolveEditorDialog;
 
 
@@ -103,24 +109,29 @@ private:
 
 
 ResolveDialog::ResolveDialog(KConfig& cfg, QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
     , markeditem(-1)
     , partConfig(cfg)
 {
-    setButtons(Close | Help | User1 | User2);
-    setButtonGuiItem(User1, KStandardGuiItem::saveAs());
-    setButtonGuiItem(User2, KStandardGuiItem::save());
-    setDefaultButton(Close);
-    showButtonSeparator(true);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
 
-    QFrame* mainWidget = new QFrame(this);
-    setMainWidget(mainWidget);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Help | QDialogButtonBox::Close);
 
-    QBoxLayout *layout = new QVBoxLayout(mainWidget);
-    layout->setSpacing(spacingHint());
-    layout->setMargin(0);
+    QPushButton *user1Button = new QPushButton;
+    buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
 
-    QSplitter *vertSplitter = new QSplitter(Qt::Vertical, mainWidget);
+    QPushButton *user2Button = new QPushButton;
+    buttonBox->addButton(user2Button, QDialogButtonBox::ActionRole);
+
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(buttonBox, &QDialogButtonBox::helpRequested, this, &ResolveDialog::slotHelp);
+
+    KGuiItem::assign(user1Button, KStandardGuiItem::saveAs());
+    KGuiItem::assign(user2Button, KStandardGuiItem::save());
+
+    QSplitter *vertSplitter = new QSplitter(Qt::Vertical, this);
+    mainLayout->addWidget(vertSplitter);
 
     QSplitter *splitter = new QSplitter(Qt::Horizontal, vertSplitter);
 
@@ -155,34 +166,34 @@ ResolveDialog::ResolveDialog(KConfig& cfg, QWidget *parent)
     merge = new DiffView(cfg, false, false, mergeLayoutWidget);
     mergeLayout->addWidget(merge, 10);
 
-    layout->addWidget(vertSplitter);
+    mainLayout->addWidget(vertSplitter);
 
-    abutton = new QPushButton("&A", mainWidget);
+    abutton = new QPushButton("&A");
     connect( abutton, SIGNAL(clicked()), SLOT(aClicked()) );
 
-    bbutton = new QPushButton("&B", mainWidget);
+    bbutton = new QPushButton("&B");
     connect( bbutton, SIGNAL(clicked()), SLOT(bClicked()) );
 
-    abbutton = new QPushButton("A+B", mainWidget);
+    abbutton = new QPushButton("A+B");
     connect( abbutton, SIGNAL(clicked()), SLOT(abClicked()) );
 
-    babutton = new QPushButton("B+A", mainWidget);
+    babutton = new QPushButton("B+A");
     connect( babutton, SIGNAL(clicked()), SLOT(baClicked()) );
 
-    editbutton = new QPushButton(i18n("&Edit"), mainWidget);
+    editbutton = new QPushButton(i18n("&Edit"));
     connect( editbutton, SIGNAL(clicked()), SLOT(editClicked()) );
 
-    nofnlabel = new QLabel(mainWidget);
+    nofnlabel = new QLabel;
     nofnlabel->setAlignment(Qt::AlignCenter);
 
-    backbutton = new QPushButton("&<<", mainWidget);
+    backbutton = new QPushButton("&<<");
     connect( backbutton, SIGNAL(clicked()), SLOT(backClicked()) );
 
-    forwbutton = new QPushButton("&>>", mainWidget);
+    forwbutton = new QPushButton("&>>");
     connect( forwbutton, SIGNAL(clicked()), SLOT(forwClicked()) );
 
     QBoxLayout *buttonlayout = new QHBoxLayout();
-    layout->addLayout(buttonlayout);
+    mainLayout->addLayout(buttonlayout);
     buttonlayout->addWidget(abutton, 1);
     buttonlayout->addWidget(bbutton, 1);
     buttonlayout->addWidget(abbutton, 1);
@@ -194,30 +205,35 @@ ResolveDialog::ResolveDialog(KConfig& cfg, QWidget *parent)
     buttonlayout->addWidget(backbutton, 1);
     buttonlayout->addWidget(forwbutton, 1);
 
-    connect( this, SIGNAL(user2Clicked()), SLOT(saveClicked()) );
-    connect( this, SIGNAL(user1Clicked()), SLOT(saveAsClicked()) );
+    connect(user2Button, SIGNAL(clicked()), SLOT(saveClicked()) );
+    connect(user1Button, SIGNAL(clicked()), SLOT(saveAsClicked()) );
+
+    mainLayout->addWidget(buttonBox);
+    buttonBox->button(QDialogButtonBox::Close)->setDefault(true);
 
     QFontMetrics const fm(fontMetrics());
-    setMinimumSize(fm.width('0') * 120,
-                   fm.lineSpacing() * 40);
-
-    setHelp("resolvingconflicts");
+    resize(fm.width('0') * 100, fm.lineSpacing() * 40);
 
     setAttribute(Qt::WA_DeleteOnClose, true);
 
     KConfigGroup cg(&partConfig, "ResolveDialog");
-    restoreDialogSize(cg);
+    restoreGeometry(cg.readEntry<QByteArray>("geometry", QByteArray()));
 }
 
 
 ResolveDialog::~ResolveDialog()
 {
     KConfigGroup cg(&partConfig, "ResolveDialog");
-    saveDialogSize(cg);
+    cg.writeEntry("geometry", saveGeometry());
 
     qDeleteAll(items);
 }
 
+void ResolveDialog::slotHelp()
+{
+  KHelpClient::invokeHelp(QLatin1String("resolvingconflicts"));
+}
+
 
 // One resolve item has a line number range of linenoA:linenoA+linecountA-1
 // in A and linenoB:linenoB+linecountB-1 in B. If the user has chosen version A
@@ -241,7 +257,7 @@ bool ResolveDialog::parseFile(const QString &name)
     int advanced1, advanced2;
     enum { Normal, VersionA, VersionB } state;
 
-    setCaption(i18n("CVS Resolve: %1", name));
+    setWindowTitle(i18n("CVS Resolve: %1", name));
 
     fname = name;
 
@@ -530,7 +546,7 @@ void ResolveDialog::choose(ChooseType ch)
             m_contentMergedVersion = contentVersionB(item) + contentVersionA(item);
             break;
         default:
-            kDebug(8050) << "Internal error at switch";
+            qCDebug(log_cervisia) << "Internal error at switch";
         }
 
     updateMergedVersion(ch);
@@ -600,7 +616,7 @@ void ResolveDialog::saveClicked()
 void ResolveDialog::saveAsClicked()
 {
     QString filename =
-        KFileDialog::getSaveFileName(KUrl(), QString(), this, QString());
+        QFileDialog::getSaveFileName(this);
 
     if( !filename.isEmpty() && Cervisia::CheckOverwrite(filename) )
         saveFile(filename);
@@ -618,7 +634,7 @@ void ResolveDialog::keyPressEvent(QKeyEvent *e)
         case Qt::Key_Up:   diff1->up();   break;
         case Qt::Key_Down: diff1->down(); break;
         default:
-            KDialog::keyPressEvent(e);
+            QDialog::keyPressEvent(e);
     }
 }
 
@@ -649,7 +665,6 @@ QString ResolveDialog::contentVersionB(const ResolveItem *item) const
     return result;
 }
 
-#include "resolvedialog.moc"
 
 
 // Local Variables:
